<?php
/*
Plugin Name: Page Importer  with Posts (Optimized)
Plugin URI: https://pablo-guides.com
Description: Import web pages as WordPress posts and register the URLs in the database. Optimized for large volumes of URLs and includes category selection.
Version: 1.0
Author: pablo rotem
Author URI: https://pablo-guides.com
License: GPL2
*/

// Add a menu item to the admin dashboard
function rent_page_importer_menu() {
    add_menu_page('Html Page Importer', 'Page Importer', 'manage_options', 'rent_page_importer', 'rent_page_importer_admin_page');
}
add_action('admin_menu', 'rent_page_importer_menu');

// Display the Page Importer admin page
function rent_page_importer_admin_page() {
    if (isset($_POST['import_urls'])) {
        $urls = isset($_POST['urls']) ? $_POST['urls'] : '';
        $category = isset($_POST['category']) ? $_POST['category'] : '';

        if (!empty($urls) && !empty($category)) {
            $urls_array = explode("\n", $urls);
            if (import_urls_as_posts($urls_array, $category)) {
                echo '<div class="updated"><p>URLs imported as posts successfully!</p></div>';
            } else {
                echo '<div class="error"><p>Error importing URLs as posts. Please try again.</p></div>';
            }
        } else {
            echo '<div class="error"><p>Please enter URLs and select a category.</p></div>';
        }
    }
    ?>
    <div class="wrap">
        <h2>Page Importer with Posts (Optimized) by pablo rotem</h2>
        <form method="post" action="">
            <label for="urls">Enter URLs (one per line):</label><br/>
            <textarea id="urls" name="urls" rows="5" cols="50"></textarea><br/><br/>

            <label for="category">Select a category:</label><br/>
            <select id="category" name="category">
                <option value="">Select Category</option>
                <?php
                $categories = get_categories();
                foreach ($categories as $cat) {
                    echo '<option value="' . $cat->term_id . '">' . $cat->name . '</option>';
                }
                ?>
            </select><br/><br/>

            <input type="submit" name="import_urls" value="Import URLs as Posts" class="button button-primary"/>
        </form>
    </div>
    <?php
}

// Function to import URLs as WordPress posts with category selection
function import_urls_as_posts($urls, $category_id) {
    foreach ($urls as $url) {
        $url = trim($url);
        if (!empty($url)) {
            $html_content = file_get_contents($url);

            // Check if HTML content exists
            if (!empty($html_content)) {
                // Extract the page name from the URL
                $page_name = basename(parse_url($url, PHP_URL_PATH));

                // Generate post title from page name
                $post_title = str_replace('-', ' ', pathinfo($page_name, PATHINFO_FILENAME));
                $post_title = ucwords($post_title);

                // Create a new post
                $post_data = array(
                    'post_title'    => $post_title,
                    'post_content'  => $html_content,
                    'post_status'   => 'publish',
                    'post_type'     => 'post',
                    'post_category' => array($category_id) // Assign the selected category to the post
                );

                // Insert the post into the database
                $post_id = wp_insert_post($post_data);

                if (!$post_id) {
                    return false; // If an error occurs during post creation, exit the function
                }
            }
        }
    }

    return true;
}
